@@ -407,10 +407,6 @@ MainWindow::initQML ()
     OsDependent &osd = Singletons::getRef().getOSD ();
     QRect rect = osd.getStartingSize ();
 
-#if defined(Q_WS_MAEMO_5)
-    this->engine()->addImportPath(QString("/opt/qtm11/imports"));
-#endif
-
     bool bTempFalse = false;
     int iTempZero = 0;
 
@@ -1474,9 +1470,11 @@ MainWindow::playVmail (const QString &strFile)
     do // Begin cleanup block (not a loop)
     {
         // Convert it into a file:// url
-        QString strUrl = QUrl::fromLocalFile(strFile).toString ();
+        QUrl url = QUrl::fromLocalFile(strFile).toString ();
 
-        vmailPlayer.setMedia (QMediaContent(strUrl));
+        qDebug() << "Play vmail file:" << strFile << "Url =" << url;
+
+        vmailPlayer.setMedia (QMediaContent(url));
         vmailPlayer.play();
     } while (0); // End cleanup block (not a loop)
 }//MainWindow::playVmail
@@ -1522,17 +1520,10 @@ MainWindow::on_actionWeb_view_triggered ()
     }
 }//MainWindow::on_actionWeb_view_triggered
 
-void
-MainWindow::on_actionLogs_triggered ()
-{
-    //
-}//MainWindow::on_actionLogs_triggered
-
 void
 MainWindow::onRegPhoneSelectionChange (int index)
 {
-    indRegPhone = index < modelRegNumber.rowCount() ?
-                  index : modelRegNumber.rowCount() - 1;
+    indRegPhone = index;
 
     CacheDatabase &dbMain = Singletons::getRef().getDBMain ();
     dbMain.putCallback (QString("%1").arg (indRegPhone));
